[git] GnuPG - branch, master, updated. gnupg-2.1.9-38-g485e0a2

by Werner Koch cvs at cvs.gnupg.org
Wed Oct 21 10:38:29 CEST 2015


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "The GNU Privacy Guard".

The branch, master has been updated
       via  485e0a221deb5c68f29b6a7a110b349dbe41c027 (commit)
       via  5055b617a94587580bc16a56bb82333077b05693 (commit)
      from  42571a38344e39f747315f754700a8181b8744fe (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit 485e0a221deb5c68f29b6a7a110b349dbe41c027
Author: Werner Koch <wk at gnupg.org>
Date:   Wed Oct 21 10:34:41 2015 +0200

    build: Make --disable-g13 the default.
    
    * Makefile.am (DISTCHECK_CONFIGURE_FLAGS): Add --enable-g13.  Remove
    --enable-gpgtar because that is enabled anyway.
    * configure.ac: Do not build g13 by default.
    --
    
    The g13 part is not very useful for a standard user right now, thus do
    not build it.
    
    Signed-off-by: Werner Koch <wk at gnupg.org>

diff --git a/Makefile.am b/Makefile.am
index 0613545..8e213f3 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -19,7 +19,7 @@
 ## Process this file with automake to produce Makefile.in
 
 ACLOCAL_AMFLAGS = -I m4
-DISTCHECK_CONFIGURE_FLAGS = --enable-symcryptrun --enable-mailto --enable-gpgtar
+DISTCHECK_CONFIGURE_FLAGS = --enable-symcryptrun --enable-mailto --enable-g13
 
 GITLOG_TO_CHANGELOG=gitlog-to-changelog
 
diff --git a/configure.ac b/configure.ac
index bdfff88..22d1cfc 100644
--- a/configure.ac
+++ b/configure.ac
@@ -114,7 +114,7 @@ GNUPG_BUILD_PROGRAM(gpgsm, yes)
 # The agent is a required part and can't be disabled anymore.
 build_agent=yes
 GNUPG_BUILD_PROGRAM(scdaemon, yes)
-GNUPG_BUILD_PROGRAM(g13, yes)
+GNUPG_BUILD_PROGRAM(g13, no)
 GNUPG_BUILD_PROGRAM(dirmngr, yes)
 GNUPG_BUILD_PROGRAM(tools, yes)
 GNUPG_BUILD_PROGRAM(doc, yes)

commit 5055b617a94587580bc16a56bb82333077b05693
Author: Werner Koch <wk at gnupg.org>
Date:   Wed Oct 21 10:29:02 2015 +0200

    dirmngr: Rename file dns-cert.c.
    
    * dirmngr/dns-cert.c: Rename to dirmngr/dns-stuff.c.
    * dirmngr/dns-cert.h: Rename to dirmngr/dns-stuff.h and change
    includers.
    * dirmngr/t-dns-cert.c: Rename to dirmngr/t-dns-stuff.c.
    * dirmngr/Makefile.am: Adjust.
    
    Signed-off-by: Werner Koch <wk at gnupg.org>

diff --git a/dirmngr/Makefile.am b/dirmngr/Makefile.am
index ae16660..8cb1bb7 100644
--- a/dirmngr/Makefile.am
+++ b/dirmngr/Makefile.am
@@ -61,7 +61,7 @@ dirmngr_SOURCES = dirmngr.c dirmngr.h server.c crlcache.c crlfetch.c	\
 	certcache.c certcache.h \
 	cdb.h cdblib.c misc.c dirmngr-err.h  \
 	ocsp.c ocsp.h validate.c validate.h  \
-	dns-cert.c dns-cert.h \
+	dns-stuff.c dns-stuff.h \
 	http.c http.h \
 	ks-action.c ks-action.h ks-engine.h \
 	ks-engine-hkp.c ks-engine-http.c ks-engine-finger.c ks-engine-kdns.c
@@ -114,7 +114,7 @@ t_common_ldadd = $(libcommon) no-libgcrypt.o $(LIBASSUAN_LIBS) \
                  $(NTBTLS_LIBS) $(LIBGNUTLS_LIBS) \
                  $(DNSLIBS) $(LIBINTL) $(LIBICONV)
 
-module_tests = t-dns-cert
+module_tests = t-dns-stuff
 
 if USE_LDAP
 module_tests += t-ldap-parse-uri
@@ -141,7 +141,7 @@ t_ldap_parse_uri_SOURCES = \
 t_ldap_parse_uri_CFLAGS = -DWITHOUT_NPTH=1
 t_ldap_parse_uri_LDADD = $(ldaplibs) $(t_common_ldadd)
 
-t_dns_cert_SOURCES = t-dns-cert.c dns-cert.c
-t_dns_cert_LDADD   = $(t_common_ldadd)
+t_dns_stuff_SOURCES = t-dns-stuff.c dns-stuff.c
+t_dns_stuff_LDADD   = $(t_common_ldadd)
 
 $(PROGRAMS) : $(libcommon) $(libcommonpth)
diff --git a/dirmngr/dns-cert.c b/dirmngr/dns-stuff.c
similarity index 98%
rename from dirmngr/dns-cert.c
rename to dirmngr/dns-stuff.c
index 712dfc0..c2d40c9 100644
--- a/dirmngr/dns-cert.c
+++ b/dirmngr/dns-stuff.c
@@ -1,7 +1,8 @@
-/* dns-cert.c - DNS CERT code (rfc-4398)
+/* dns-stuff.c - DNS related code including CERT RR (rfc-4398)
  * Copyright (C) 2005, 2006, 2009 Free Software Foundation, Inc.
+ * Copyright (C) 2005, 2006, 2009, 2015 Werner Koch
  *
- * This file is part of GNUPG.
+ * This file is part of GnuPG.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of either
@@ -48,7 +49,7 @@
 
 #include "util.h"
 #include "host2net.h"
-#include "dns-cert.h"
+#include "dns-stuff.h"
 
 /* Not every installation has gotten around to supporting CERTs
    yet... */
diff --git a/dirmngr/dns-cert.h b/dirmngr/dns-stuff.h
similarity index 86%
rename from dirmngr/dns-cert.h
rename to dirmngr/dns-stuff.h
index e5cd4eb..aea0e69 100644
--- a/dirmngr/dns-cert.h
+++ b/dirmngr/dns-stuff.h
@@ -1,5 +1,6 @@
-/* dns-cert.h - DNS CERT definition
+/* dns-stuff.c - DNS related code including CERT RR (rfc-4398)
  * Copyright (C) 2006 Free Software Foundation, Inc.
+ * Copyright (C) 2006, 2015 Werner Koch
  *
  * This file is part of GnuPG.
  *
@@ -26,8 +27,8 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
-#ifndef GNUPG_DIRMNGR_DNS_CERT_H
-#define GNUPG_DIRMNGR_DNS_CERT_H
+#ifndef GNUPG_DIRMNGR_DNS_STUFF_H
+#define GNUPG_DIRMNGR_DNS_STUFF_H
 
 
 #define DNS_CERTTYPE_ANY       0 /* Internal catch all type. */
@@ -47,7 +48,11 @@
 #define DNS_CERTTYPE_RRBASE 1024 /* Base of special constants.  */
 #define DNS_CERTTYPE_RR61   (DNS_CERTTYPE_RRBASE + 61)
 
+/* Calling this function switches the DNS code into Tor mode if
+   possibe.  Return 0 on success.  */
 gpg_error_t enable_dns_tormode (void);
+
+/* Return a CERT record or an arbitray RR.  */
 gpg_error_t get_dns_cert (const char *name, int want_certtype,
                           void **r_key, size_t *r_keylen,
                           unsigned char **r_fpr, size_t *r_fprlen,
@@ -55,4 +60,4 @@ gpg_error_t get_dns_cert (const char *name, int want_certtype,
 
 
 
-#endif /*GNUPG_DIRMNGR_DNS_CERT_H*/
+#endif /*GNUPG_DIRMNGR_DNS_STUFF_H*/
diff --git a/dirmngr/server.c b/dirmngr/server.c
index f6225d4..23ecdd8 100644
--- a/dirmngr/server.c
+++ b/dirmngr/server.c
@@ -50,7 +50,7 @@
 #if USE_LDAP
 # include "ldap-parse-uri.h"
 #endif
-#include "dns-cert.h"
+#include "dns-stuff.h"
 #include "mbox-util.h"
 
 /* To avoid DoS attacks we limit the size of a certificate to
diff --git a/dirmngr/t-dns-cert.c b/dirmngr/t-dns-stuff.c
similarity index 92%
rename from dirmngr/t-dns-cert.c
rename to dirmngr/t-dns-stuff.c
index 61536c5..e34f809 100644
--- a/dirmngr/t-dns-cert.c
+++ b/dirmngr/t-dns-stuff.c
@@ -1,5 +1,6 @@
 /* t-dns-cert.c - Module test for dns-cert.c
  * Copyright (C) 2011 Free Software Foundation, Inc.
+ * Copyright (C) 2011, 2015 Werner Koch
  *
  * This file is part of GnuPG.
  *
@@ -23,7 +24,7 @@
 #include <assert.h>
 
 #include "util.h"
-#include "dns-cert.h"
+#include "dns-stuff.h"
 
 
 int
@@ -49,7 +50,7 @@ main (int argc, char **argv)
     name = *argv;
   else
     {
-      fputs ("usage: t-dns-cert [name]\n", stderr);
+      fputs ("usage: t-dns-stuff [name]\n", stderr);
       return 1;
     }
 

-----------------------------------------------------------------------

Summary of changes:
 Makefile.am                             |  2 +-
@@ -1,5 +1,6 @@
-/* t-dns-cert.c - Module test for dns-cert.c
+/* t-dns-cert.c - Module test for dns-stuff.c
  * Copyright (C) 2011 Free Software Foundation, Inc.
 configure.ac                            |  2 +-
 dirmngr/Makefile.am                     |  8 ++++----
 dirmngr/{dns-cert.c => dns-stuff.c}     |  7 ++++---
 dirmngr/{dns-cert.h => dns-stuff.h}     | 13 +++++++++----
 dirmngr/server.c                        |  2 +-
 dirmngr/{t-dns-cert.c => t-dns-stuff.c} |  7 ++++---
 7 files changed, 24 insertions(+), 17 deletions(-)
 rename dirmngr/{dns-cert.c => dns-stuff.c} (98%)
 rename dirmngr/{dns-cert.h => dns-stuff.h} (86%)
 rename dirmngr/{t-dns-cert.c => t-dns-stuff.c} (92%)


hooks/post-receive
-- 
The GNU Privacy Guard
http://git.gnupg.org




More information about the Gnupg-commits mailing list